@@ -3,13 +3,13 @@ from django.test import TestCase
 from models import GroupStat, GroupStatistic
 from vkontakte_groups.factories import GroupFactory
 
-GROUP_ID = 30221121
+GROUP_ID = 1
 
 class VkontakteGroupsStatisticTest(TestCase):
 
     def test_fetch_statistic(self):
 
-        group = GroupFactory.create(remote_id=GROUP_ID)
+        group = GroupFactory(remote_id=GROUP_ID)
         self.assertEqual(GroupStat.objects.count(), 0)
 
         group.fetch_statistic()
@@ -25,10 +25,10 @@ class VkontakteGroupsStatisticTest(TestCase):
 
     def test_fetch_statistic_via_api(self):
 
-        group = GroupFactory.create(remote_id=GROUP_ID)
+        group = GroupFactory(remote_id=GROUP_ID)
         self.assertEqual(GroupStatistic.objects.count(), 0)
 
-        group.fetch_statistic(api=True)
+        group.fetch_statistic(source='api')
         self.assertNotEqual(GroupStatistic.objects.count(), 0)
 
         stat = GroupStatistic.objects.all()[0]
